package com.ghy.order.mapper;

import com.ghy.order.domain.OrderOperationRecord;

import java.util.List;

/**
 * 订单操作记录Mapper接口
 *
 * @author clunt
 * @date 2024-02-17
 */
public interface OrderOperationRecordMapper
{
    /**
     * 查询订单操作记录
     *
     * @param id 订单操作记录主键
     * @return 订单操作记录
     */
    public OrderOperationRecord selectOrderOperationRecordById(Long id);

    /**
     * 查询订单操作记录列表
     *
     * @param orderOperationRecord 订单操作记录
     * @return 订单操作记录集合
     */
    public List<OrderOperationRecord> selectOrderOperationRecordList(OrderOperationRecord orderOperationRecord);

    /**
     * 新增订单操作记录
     *
     * @param orderOperationRecord 订单操作记录
     * @return 结果
     */
    public int insertOrderOperationRecord(OrderOperationRecord orderOperationRecord);

    /**
     * 修改订单操作记录
     *
     * @param orderOperationRecord 订单操作记录
     * @return 结果
     */
    public int updateOrderOperationRecord(OrderOperationRecord orderOperationRecord);

    /**
     * 删除订单操作记录
     *
     * @param id 订单操作记录主键
     * @return 结果
     */
    public int deleteOrderOperationRecordById(Long id);

    /**
     * 批量删除订单操作记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderOperationRecordByIds(String[] ids);
}
